
#ifndef _C10_ev462_
#define _C10_ev462_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_REFERENCE F1097_9804(EIF_REFERENCE);
extern void EIF_Minit462(void);
extern EIF_REFERENCE F1094_9783(EIF_REFERENCE);

#ifdef __cplusplus
}
#endif

#endif
